function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}

var app = angular.module('myApp', ['component', 'loadMore']);
app.controller('myCtrl', function ($scope, $http) {
    $scope.data = {
        "pageText": JSON.parse(android.getJsonFromFile("notify_pageText")),
        "accountInfo": JSON.parse(android.getAccountInfo()),
        "reqUrl": {
            "list": android.getReqUrl("notifylist"),
            "detail": android.getReqUrl("notifydetail")
        },
        "warnData": {
            "showWarn": false,
            "warnMsg": null
        },
        "list_dom": document.getElementById("list"),
        "show_detail": false,
        "header": {
            "title": android.getString("title_notify"),
            "backtext": android.getString('back')
        },
        "headerTitle": {
            "notifylist": android.getString("title_notify"),
            "detail": android.getString("title_notifyContent")
        },
        "warnning_and_error": {
            "network_unavailable": android.getString("network_unavailable"),
            "notifylist_error": android.getString("notifylist_error"),
            "notifydetail_error": android.getString("notifydetail_error")
        },
        "myListConfig": {
            "page": 1,
            "pagesize": 6
        },
        "notifyList": null,
        "detail": null,
        "flag": true,
        "pullToLoadMore": {
            "show": false,
            "loading": false,
            "text": android.getString("loading")
        },
        "more": true,
        "parseDate": {
            "today": {
                "value": "",
                "text": android.getString("today")
            },
            "yesterday": {
                "value": "",
                "text": android.getString("yesterday")
            }
        }
    };
    $scope.init = function () {
        if (!String.prototype.includes) {
            String.prototype.includes = function (search, start) {
                'use strict';
                if (typeof start !== 'number') {
                    start = 0;
                }

                if (start + search.length > this.length) {
                    return false;
                } else {
                    return this.indexOf(search, start) !== -1;
                }
            };
        }
        var today = new Date();
        this.data.parseDate.today.value = today.toLocaleDateString("ch-ZN", {
            hour12: false
        }).replace(/\//g, "-").replace(/-(?!\d\d)/g, "-0");
        this.data.parseDate.yesterday.value = new Date(today.valueOf() - 86400000).toLocaleDateString("ch-ZN", {
            hour12: false
        }).replace(/\//g, "-").replace(/-(?!\d\d)/g, "-0");
        this.data.header.title = this.data.headerTitle.notifylist;
        this.refresh();
    };
    $scope.isNetworkAvailable = function () {
        if (android.isNetworkAvailable()) {
            this.data.warnData.showWarn = false;
            return true;
        } else {
            this.data.warnData.warnMsg = this.data.warnning_and_error.network_unavailable;
            this.data.warnData.showWarn = true;
            return false;
        }
    };
    $scope.show_notification = function (detail) {
        if (detail) {
            this.data.currNotification = detail;
        }
        if (this.isNetworkAvailable()) {
            android.setRefresh();
            $http({
                url: $scope.data.reqUrl.detail,
                data: JSON.stringify({
                    "hrid": $scope.data.accountInfo.hrid,
                    "penum": $scope.data.accountInfo.penum,
                    "notifynum": detail.notifynum
                }),
                method: "POST",
                responseType: "json",
                timeout: 1000
            }).success(function (res) {
                if (res.success) {
                    var temObj = {
                        "createdate": res.content.createdate,
                        "title": res.content.title,
                        "description": res.content.description,
                        "createbyname": res.content.createbyname
                    };
                    $scope.data.detail = temObj;
                    detail.reading = "1";
                } else {
                    android.alert(res.message);
                }
                android.refreshComplete();
            }).error(function () {
                android.refreshComplete();
                android.alert($scope.data.warnning_and_error.notifydetail_error);
            });
            this.data.header.title = this.data.headerTitle.detail;
            this.data.show_detail = true;
            android.setRefreshDisable();
        }
    };
    $scope.refresh = function () {
        this.data.myListConfig.page = 1;
        this.getMyList(true);
    };
    $scope.loadMore = function () {
        $scope.data.pullToLoadMore = {
            "show": true,
            "loading": true,
            "text": android.getString("loading")
        };
        this.getMyList();
    };
    $scope.getMyList = function (isrefresh) {
        if (this.isNetworkAvailable()) {
            android.setRefresh();
            $http({
                url: $scope.data.reqUrl.list,
                data: JSON.stringify({
                    "hrid": $scope.data.accountInfo.hrid,
                    "penum": $scope.data.accountInfo.penum,
                    "page": $scope.data.myListConfig.page,
                    "pagesize": $scope.data.myListConfig.pagesize
                }),
                method: "POST",
                responseType: "json"
            }).success(function (res) {
                if (res.success) {
                    $scope.data.myListConfig.page++;
                    if (isrefresh) $scope.data.notifyList = $scope.parseDate(res.content);
                    else $scope.data.notifyList = $scope.data.notifyList.concat($scope.parseDate(res.content));
                    var more = Boolean(res.total == $scope.data.myListConfig.pagesize);
                    if (more) {
                        $scope.data.pullToLoadMore = {
                            "show": false,
                            "loading": false
                        };
                    } else {
                        $scope.data.pullToLoadMore = {
                            "show": true,
                            "loading": false,
                            "text": android.getString("no_more")
                        };
                    }
                    $scope.data.more = more;
                    if ($scope.data.flag) {
                        $scope.data.flag = false;
                        var notifynum = notifyApi.getNotifyNum();
                        if (notifynum) {
                            var list = res.content;
                            var len = list.length;
                            for (var i = 0; i < len; i++) {
                                if (list[i].notifynum == notifynum) {
                                    $scope.show_notification(list[i]);
                                    break;
                                }
                            }
                        }
                    }
                } else {
                    android.alert(res.message);
                }
                android.refreshComplete();
            }).error(function () {
                android.refreshComplete();
                android.alert($scope.data.warnning_and_error.notifylist_error);
            });
        }
    };
    $scope.parseDate = function (arr) {
        var todayVal = this.data.parseDate.today.value,
            todayText = this.data.parseDate.today.text,
            yesterdayVal = this.data.parseDate.yesterday.value,
            yesterdayText = this.data.parseDate.yesterday.text;
        arr.forEach(function (item) {
            if (item.createdate.includes(todayVal)) {
                item.createdate = item.createdate.replace(todayVal, todayText);
            } else if (item.createdate.includes(yesterdayVal)) {
                item.createdate = item.createdate.replace(yesterdayVal, yesterdayText);
            }
        });
        return arr;
    };
    $scope.back = function () {
        if (this.data.show_detail) {
            this.data.header.title = this.data.headerTitle.notifylist;
            this.data.show_detail = false;
            this.data.detail = {};
            android.setRefreshEnabled();
            return false;
        } else
            notifyApi.goback();
    };
    $scope.btn_click = function () {
        if (this.data.show_detail) {
            this.data.header.title = this.data.headerTitle.notifylist;
            this.data.show_detail = false;
            this.data.detail = {};
        } else
            notifyApi.createNotification();
    };
});

function pullToRefresh() {
    var ele = angular.element(document.getElementById("myCtrl"));
    var myCtrlScope = ele.scope();
    myCtrlScope.$apply(function () {
        myCtrlScope.refresh();
    });
    if (myCtrlScope.data.show_detail) {
        myCtrlScope.$apply(function () {
            myCtrlScope.show_notification(myCtrlScope.data.currNotification);
        });
    }
}

function pullToLoadMore() {
    var ele = angular.element(document.getElementById("myCtrl"));
    var scope = ele.scope();
    if (scope.data.show_detail) return;
    scope.$apply(function () {
        return scope.loadMore();
    });
}

function back() {
    var ele = angular.element(document.getElementById("myCtrl"));
    var scope = ele.scope();
    scope.$apply(function () {
        scope.back();
    });
}