var app = angular.module("myApp", ["component", "loadMore"]);
app.controller("myCtrl", function ($scope, $http) {
    var _this = this;
    $scope.data = {
        "pageText": JSON.parse(android.getJsonFromFile("query_pageText")),
        "accountInfo": JSON.parse(android.getAccountInfo()),
        "show": false,
        "list": [], //列表
        "resultList": [], //用于返回的数组
        "temList": [], //用于中间操作的数组
        "checkedList": [], //用于初始遍历状态的数组
        "reqUrl": "",
        "reqData": {},
        "warnData": {
            "showWarn": false,
            "warnMsg": ""
        },
        "header": {
            "back": android.getString("back")
        },
        "warnning_and_error": {
            "network_unavailable": android.getString("network_unavailable")
        },
        "myListConfig": {
            "page": 1,
            "pagesize": 30
        },
        "pullToLoadMore": {
            "show": false,
            "loading": false,
            "text": android.getString("loading")
        }
    };
    $scope.init = function () {
        this.data.reqUrl = android.getReqUrl("accountlist");
        this.refresh();
        this.data.resultList = this.getPageData();
        this.data.resultList.forEach(function (item, index) {
            $scope.data.temList.push({
                "listIndex": item.listIndex,
                "checkedListIndex": index
            })
        })
        this.data.checkedList = this.getPageData();
    };
    $scope.loadMore = function () {
        $scope.data.pullToLoadMore = {
            "show": true,
            "loading": true,
            "text": android.getString("loading")
        };
        this.getMyList();
    };
    $scope.getPageData = function () {
        var tem = JSON.parse(queryApi.getPageData());
        return tem ? tem : [];
    };
    $scope.show = function () {
        this.data.show = !this.data.show;
    };
    $scope.select = function (index) {
        var currItem = this.data.list[index];
        if (!currItem.checked) {
            for (var i = 0, checkedItemsLen = this.data.temList.length; i < checkedItemsLen; i++) {
                if (this.data.temList[i]) {
                    if (this.data.temList[i].listIndex == index) {
                        this.removeItem(this.data.temList[i].checkedListIndex);
                        return true;
                    }
                }
            }
        } else {
            var lastIndex = this.data.resultList.length;
            currItem.listIndex = index;
            this.data.resultList.push(currItem);
            this.data.temList.push({
                "listIndex": index,
                "checkedListIndex": lastIndex
            });
        }
    };
    $scope.removeItem = function (index) {
        var listIndex = this.data.resultList[index].listIndex;
        this.data.resultList.splice(index, 1);
        this.data.list[listIndex].checked = false;

        var remove = false;
        for (var i = 0, checkedItemsLen = this.data.temList.length; i < checkedItemsLen; i++) {
            if (this.data.temList[i]) {
                if (this.data.temList[i].listIndex == listIndex) {
                    this.data.temList.splice(i, 1);
                    i--;
                    checkedItemsLen--;
                    remove = true;
                } else if (remove) this.data.temList[i].checkedListIndex--;
            }
        }
        if (this.data.resultList.length == 0) this.data.show = false;
    };
    $scope.back = function () {
        queryApi.goback();
    };
    $scope.refresh = function () {
        this.data.myListConfig.page = 1;
        this.getMyList(true);
    };
    $scope.getMyList = function (isrefresh) {
        if (!android.isNetworkAvailable()) {
            _this.data.warnData.warnMsg = _this.data.warnning_and_error.network_unavailable;
            _this.data.warnData.showWarn = true;
        } else {
            $http({
                url: $scope.data.reqUrl,
                data: JSON.stringify({
                    "hrid": $scope.data.accountInfo.hrid,
                    "penum": $scope.data.accountInfo.penum,
                    "page": $scope.data.myListConfig.page,
                    "pagesize": $scope.data.myListConfig.pagesize
                }),
                method: "POST",
                responseType: "json"
            }).success(function (res) {
                if (res.success) {
                    $scope.data.myListConfig.page++;
                    var more = Boolean(res.total == $scope.data.myListConfig.pagesize);
                    if (more) {
                        $scope.data.pullToLoadMore = {
                            "show": false,
                            "loading": false
                        };
                    } else {
                        $scope.data.pullToLoadMore = {
                            "show": true,
                            "loading": false,
                            "text": android.getString("no_more")
                        };
                    }
                    $scope.data.more = more;
                    var temArr = [];
                    //循环比较获取已选中人员更改状态
                    for (var i = 0, listLen = res.total; i < listLen; i++) {
                        if ($scope.data.checkedList.length) {
                            for (var j = 0, len = $scope.data.checkedList.length; j < len; j++) {
                                if ($scope.data.checkedList[j].id == res.content[i].hrid) {
                                    res.content[i].checked = true;
                                    // $scope.data.checkedList.splice(j, 1);
                                    break;
                                }
                            }
                        }
                        temArr.push({
                            "id": res.content[i].hrid,
                            "name": res.content[i].displayname,
                            "checked": res.content[i].checked ? res.content[i].checked : false
                        });
                    }
                    if (isrefresh) $scope.data.list = temArr;
                    else $scope.data.list = $scope.data.list.concat(temArr);
                } else android.alert(res.message);
                android.refreshComplete();
            }).error(function () {
                android.refreshComplete();
                android.alert(android.getString("accountlist_error"));
            });
        }
    };
    $scope.save = function () {
        var resultList = [];
        if (this.data.resultList) {
            this.data.resultList.forEach(function (item) {
                resultList.push({
                    id: item.id,
                    listIndex: item.listIndex,
                    name: item.name
                })
            })
        }
        queryApi.setResultData(JSON.stringify(resultList));
    };
});

function pullToRefresh() {
    var ele = angular.element(document.getElementById("myCtrl"));
    var myCtrlScope = ele.scope();
    myCtrlScope.$apply(function () {
        myCtrlScope.refresh();
    });
}