var app = angular.module("myApp", ["component", "loadMore"]);
app.controller("myCtrl", function ($scope, $http) {
    $scope.data = {
        "pageText": null,
        "header": {
            "title": android.getString("title_rcwotask"),
            "backtext": android.getString("back")
        },
        "reqUrl": android.getReqUrl("tasklist"),
        "accountInfo": JSON.parse(android.getAccountInfo()),
        "rctasklist": [],
        "pullToLoadMore": {
            "show": false,
            "loading": false,
            "text": android.getString("loading")
        },
        "myListConfig": {
            "page": 1,
            "pagesize": 20,
            "istemp": "0"
        },
        "more": true,
        "warning_and_error": {
            "rcwotask_error": android.getString("rcwotask_error")
        },
        "warnData": {
            "showWarn": false,
            "warnMsg": android.getString("network_unavailable")
        },
        "searchbar": {
            "searchText": "",
            "focus": false,
            "placeholder": "",
            "button": ""
        },
        "frequnit": {
            "MINUTE": android.getString("MINUTE"),
            "HOUR": android.getString("HOUR"),
            "DAY": android.getString("DAY"),
            "WEEK": android.getString("WEEK"),
            "MONTH": android.getString("MONTH"),
            "YEAR": android.getString("YEAR")
        }
    };
    $scope.scan = function () {
        rctaskApi.scan();
    };
    $scope.init = function () {
        this.data.pageText = JSON.parse(android.getJsonFromFile("rctask_pageText"));
        this.data.searchbar.placeholder = this.data.pageText.search_placeholder;
        this.data.searchbar.button = this.data.pageText.search_button;
        this.getTask(true);
    };
    $scope.refresh = function () {
        this.data.myListConfig.page = 1;
        this.data.pullToLoadMore = {
            "show": false,
            "loading": false,
            "text": android.getString("loading")
        };
        this.getTask(true);
        this.data.more = true;
    };
    $scope.loadMore = function () {
        this.data.pullToLoadMore.show = true, this.data.pullToLoadMore.loading = true, this.data.pullToLoadMore.text = android.getString("loading");
        this.getTask();
    };
    $scope.getTask = function (refresh) {
        var _this = this;

        if (android.isNetworkAvailable()) {
            if(refresh) 
                android.setRefresh();
            $http({
                url: $scope.data.reqUrl,
                data: JSON.stringify({
                    "hrid": $scope.data.accountInfo.hrid,
                    "penum": $scope.data.accountInfo.penum,
                    "page": $scope.data.myListConfig.page,
                    "pagesize": 20,
                    "istemp": $scope.data.myListConfig.istemp
                }),
                method: "post",
                responseType: "json"
            }).success(function (res) {
                if (res.success) {
                    _this.data.myListConfig.page++;
                    res.content.forEach(function (item) {
                        item.frequnit = $scope.data.frequnit[item.frequnit];
                    });
                    var nomore = Boolean(_this.data.myListConfig.page > res.pages);
                    if (nomore) {
                        _this.data.more = false;
                        _this.data.pullToLoadMore = {
                            "show": true,
                            "loading": false,
                            "text": android.getString("no_more")
                        };
                    } else {
                        _this.data.pullToLoadMore.show = false, _this.data.pullToLoadMore.loading = false;
                    }
                    if (refresh) {
                        _this.data.rctasklist = res.content;
                        android.refreshComplete();
                    } else {
                        _this.data.rctasklist = _this.data.rctasklist.concat(res.content);
                    }
                } else {
                    android.showToast(res.message);
                }
            }).error(function () {
                android.refreshComplete();
                android.showToast($scope.data.warning_and_error.rcwotask_error);
            });
        } else {
            this.data.warnData.showWarn = true;
        }
    };
    $scope.back = function () {
        rctaskApi.goback();
    };
    $scope.openRctask = function (description, tasknum) {
        rctaskApi.openActWithData("rctask.RctaskDetail", JSON.stringify({
            "description": description,
            "tasknum": tasknum
        }));
    };
});

function pullToRefresh() {
    var ele = angular.element(document.getElementById("myCtrl"));
    var scope = ele.scope();
    scope.$apply(function () {
        scope.refresh();
    });
}

function getScanResult(result) {
    var ele = angular.element(document.getElementById("myCtrl"));
    var scope = ele.scope();
    scope.$apply(function () {
        scope.data.searchbar.searchText = result;
    });
}