'use strict';

var app = angular.module('myApp', ['component']);
app.controller('myCtrl', function ($scope, $http) {
    $scope.data = {
        "header": {
            "title": "",
            "backtext": android.getString("back")
        },
        "lang": "",
        "tagList": [{
            "text": android.getString("within_7_days"),
            "datascope": "1"
        }, {
            "text": android.getString("within_30_days"),
            "datascope": "2"
        }, {
            "text": android.getString("this_month"),
            "datascope": "4"
        }, {
            "text": android.getString("last_month"),
            "datascope": "5"
        }],
        "currentDatascope": "1",
        "type": "",
        "reqUrl": {
            "pie": "",
            "line": ""
        },
        "accountInfo": JSON.parse(android.getAccountInfo()),
        "chartLen": {
            "pieChartLen": [],
            "barChartLen": [],
            "lineChartLen": []
        },
        "chartObj": {
            "pieChartObj": [],
            "barChartObj": [],
            "lineChartObj": []
        },

        "chartData": {
            "rcwo": {
                "pie": {
                    "compcount": null,
                    "tocount": null,
                    "overtimecount": null,
                    "cancount": null,
                    "totalcount": null,
                    "datalist": null
                },
                "line": {
                    "datelist": null,
                    "linelist": null
                }
            },
            "event": {
                "pie": {
                    "compcount": null,
                    "wfpcount": null,
                    "cancount": null,
                    "totalcount": null,
                    "datalist": null
                },
                "line": {
                    "datelist": null,
                    "linelist": null
                }
            },
            "hr": {
                "datalist": null,
                "hrArr": null,
                "colorlist": ["#29c98b", "#ff5a5a", "#7cc8f8", "#dddddd", "#FFA100", "#b56ef1", "#f16e90", "#83c399", "#83a4c3", "#c7d76f"]
            },
            "abnormal": {
                "pie": {
                    "datalist": null
                },
                "line": {
                    "datelist": null,
                    "linelist": null
                },
                "colorlist": ["#29c98b", "#ff5a5a", "#7cc8f8", "#dddddd", "#FFA100", "#b56ef1", "#f16e90", "#83c399", "#83a4c3", "#c7d76f"]
            }
        },
        "reqType": {
            "pie": true,
            "line": true
        },
        "warnData": {
            "showWarn": false,
            "warnMsg": ""
        },
        "warning_and_error": {
            "server_error": android.getString("getstatistics_failed")
        }
    };
    $scope.init = function () {
        this.data.lang = android.getsyslang();
        this.data.type = statisticApi.getPageData();
        switch (this.data.type) {
            case "rcwo":
                this.data.chartLen.barChartLen.push("");
                this.data.chartLen.pieChartLen.push("");
                // this.data.chartLen.lineChartLen.push("");
                this.data.reqUrl.pie = android.getReqUrl("rcwopie");
                // this.data.reqUrl.line = android.getReqUrl("rcwoline");
                this.data.header.title = android.getString("title_rcwostat");
                break;
            case "event":
                this.data.chartLen.barChartLen.push("");
                this.data.chartLen.pieChartLen.push("");
                // this.data.chartLen.lineChartLen.push("");
                this.data.reqUrl.pie = android.getReqUrl("eventpie");
                // this.data.reqUrl.line = android.getReqUrl("eventline");
                this.data.header.title = android.getString("title_eventstat");
                break;
            case "abnormal":
                this.data.chartLen.barChartLen.push("");
                this.data.chartLen.pieChartLen.push("");
                // this.data.chartLen.lineChartLen.push("");
                this.data.reqUrl.pie = android.getReqUrl("locpie");
                // this.data.reqUrl.line = android.getReqUrl("locline");
                this.data.header.title = android.getString("title_abnormalstat");
                break;
            case "hr":
                this.data.chartLen.barChartLen.push("");
                this.data.chartLen.pieChartLen = Array.apply(null, {
                    length: 5
                });
                this.data.reqUrl.pie = android.getReqUrl("hrpie");
                this.data.header.title = android.getString("title_hrstat");
                break;
        }
        this.getData();
    };
    $scope.isNetworkAvailable = function () {
        if (android.isNetworkAvailable()) {
            this.data.warnData.showWarn = false;
            return true;
        } else {
            this.data.warnData.showWarn = true;
            this.data.warnData.warnMsg = android.getString("network_unavailable");
            android.refreshComplete();
            return false;
        }
    };
    $scope.getData = function () {
        if (this.isNetworkAvailable()) {
            android.setRefresh();
            this.data.reqType.pie = false;
            this.ajax(this.data.type, "pie", this.data.reqUrl.pie);
            if (this.data.reqUrl.line) {
                this.data.reqType.line = false;
                this.ajax(this.data.type, "line", this.data.reqUrl.line);
            }
        }
    };
    $scope.ajax = function (type, reqType, reqUrl) {
        $http({
            url: reqUrl,
            data: {
                "hrid": $scope.data.accountInfo.hrid,
                "penum": $scope.data.accountInfo.penum,
                "datascope": $scope.data.currentDatascope
            },
            method: "POST",
            responseType: "json",
            timeout: 10000
        }).success(function (res) {
            $scope.data.reqType[reqType] = true;
            $scope.checkReqType();
            if (res.success) {
                $scope.handler(type, reqType, res);
            } else {
                android.alert(res.message);
            }
        }).error(function () {
            $scope.data.reqType[reqType] = true;
            $scope.checkReqType();
            android.alert($scope.data.warning_and_error.server_error);
        });
    };
    $scope.checkReqType = function () {
        if ($scope.data.reqType.pie && $scope.data.reqType.line) {
            android.refreshComplete();
        }
    };
    $scope.handler = function (type, reqType, res) {
        switch (type) {
            case "rcwo":
                this.rcwoHandler(reqType, res);
                break;
            case "event":
                this.eventHandler(reqType, res);
                break;
            case "abnormal":
                this.abnormalHandler(reqType, res);
                break;
            case "hr":
                this.hrHandler(reqType, res);
                break;
        }
    };
    $scope.rcwoHandler = function (reqType, res) {
        if (reqType == "pie") {
            this.rcwoPieHandler(res.content);
        } else if (reqType = "line") {
            this.rcwoLineHandler(res.dateArr, res.content);
        }
    };
    $scope.eventHandler = function (reqType, res) {
        if (reqType == "pie") {
            this.eventPieHandler(res.content);
        } else if (reqType == "line") {
            this.eventLineHandler(res.dateArr, res.content);
        }
    };
    $scope.abnormalHandler = function (reqType, res) {
        if (reqType == "pie") {
            this.abnormalPieHandler(res.content);
        } else if (reqType == "line") {
            this.abnormalLineHandler(res.dateArr, res.content);
        }
    };
    $scope.hrHandler = function (reqType, res) {
        if (reqType == "pie") {
            this.hrPieHandler(res.content, res.hrArr);
        } else if (reqType == "line") {
            this.hrLineHandler(content);
        }
    };
    $scope.rcwoPieHandler = function (content) {
        //巡检执行效率饼图、柱状图处理
        this.data.chartData.rcwo.pie.compcount = content[0].total;
        this.data.chartData.rcwo.pie.tocount = content[1].total;
        this.data.chartData.rcwo.pie.overtimecount = content[2].total;
        this.data.chartData.rcwo.pie.cancount = content[3].total;
        this.data.chartData.rcwo.pie.totalcount = content[4].total;
        this.data.chartData.rcwo.pie.datalist = content;
        this.createPieChart("rcwo");
        this.createBarChart("rcwo");
    };
    $scope.rcwoLineHandler = function (dateArr, content) {
        //巡检执行效率折线图处理
        if (dateArr.length > 0 && content.length > 0) {
            this.data.chartData.rcwo.line.datelist = dateArr;
            this.data.chartData.rcwo.line.linelist = content;
            this.createLineChart("rcwo");
        }
    };
    $scope.eventPieHandler = function (content) {
        //事件报告统计饼图、柱状图处理
        if (content.length > 0) {
            this.data.chartData.event.pie.compcount = content[0].total;
            this.data.chartData.event.pie.wfpcount = content[1].total;
            this.data.chartData.event.pie.cancount = content[2].total;
            this.data.chartData.event.pie.totalcount = content[3].total;
            this.data.chartData.event.pie.datalist = content;
            this.createBarChart("event");
            this.createPieChart("event");
        }
    };
    $scope.eventLineHandler = function (dateArr, content) {
        //事件报告统计折线图处理
        if (dateArr.length > 0 && content.length > 0) {
            this.data.chartData.event.line.datelist = dateArr;
            this.data.chartData.event.line.linelist = content;
            this.createEventLineChart();
        }
    };
    $scope.abnormalPieHandler = function (content) {
        //巡查异常项统计饼图、柱状图处理
        // if (content.length >= 10) {
        //     this.data.chartData.abnormal.pie.datalist = content;
        //     this.createBarChart(this.currentTab);
        //     this.createPieChart(this.currentTab);
        // } else if (content.length > 0 && content.length < 10) {
        //     this.data.chartData.abnormal.pie.datalist = content;
        //     for (var i = 0; i < 10 - this.data.chartData.abnormal.pie.datalist.length; i++) {
        //         this.data.chartData.abnormal.pie.datalist.push({
        //             total: 0,
        //             description: ''
        //         });
        //     }
        //     this.createBarChart("abnormal");
        //     this.createPieChart("abnormal");
        if(content.length){
            this.data.chartData.abnormal.pie.datalist = content;
            this.createBarChart("abnormal");
            this.createPieChart("abnormal");
        } else {
            this.data.chartData.abnormal.pie.datalist = [{
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }, {
                total: 0,
                description: ''
            }];
            this.createBarChart("abnormal");
            this.createPieChart("abnormal");
        }
    };
    $scope.abnormalLineHandler = function (dateArr, content) {
        //巡查异常项统计折线图处理
        if (dateArr.length >= 0 && content.length >= 0) {
            this.data.chartData.abnormal.line.datelist = dateArr;
            this.data.chartData.abnormal.line.linelist = content;
            this.createLineChart("abnormal");
        }
    };
    $scope.hrPieHandler = function (content, hrArr) {
        //人员执行效率饼图处理
        this.data.chartData.hr.datalist = content;
        this.data.chartData.hr.hrArr = hrArr;
        // if (hrArr.length >= 10) {
        //     this.data.chartData.hr.datalist = content;
        //     this.data.chartData.hr.hrArr = hrArr;
        // } else {
        // if(hrArr.length < 10){
        //     this.data.chartData.hr.datalist = content;
        //     this.data.chartData.hr.hrArr = hrArr;
        //     var length = 10 - this.data.chartData.hr.hrArr.length;
        //     for (var i = 0; i < length; i++) {
        //         this.data.chartData.hr.hrArr.push('');
        //     }
        //     for (var i = 0; i < this.data.chartData.hr.datalist.length; i++) {
        //         var length = 10 - this.data.chartData.hr.datalist[i].total.length;
        //         for (var j = 0; j < length; j++) {
        //             this.data.chartData.hr.datalist[i].total.push(0);
        //         }
        //     }
        // }
        this.createHrBarChart();
        for (var i = 0, len = this.data.chartData.hr.datalist.length; i < len; i++) {
            this.createHrPieChart(i);
        }
    };
    $scope.createPieChart = function (type) {
        switch (type) {
            case "rcwo":
                this.createRcwoPieChart();
                break;
            case "event":
                this.createEventPieChart();
                break;
            case "abnormal":
                this.createAbnormalPieChart();
                break;
            case "hr":
                this.createHrPieChart();
                break;
        }
    };
    $scope.createBarChart = function (type) {
        switch (type) {
            case "rcwo":
                this.createRcwoBarChart();
                break;
            case "event":
                this.createEventBarChart();
                break;
            case "abnormal":
                this.createAbnormalBarChart();
                break;
            case "hr":
                this.createHrBarChart();
                break;
        }
    };
    $scope.createLineChart = function (type) {
        switch (type) {
            case "rcwo":
                this.createRcwoLineChart();
                break;
            case "event":
                this.createEventLineChart();
                break;
            case "abnormal":
                this.createAbnormalLineChart();
                break;
            case "hr":
                this.createHrLineChart();
                break;
        }
    };
    $scope.createRcwoPieChart = function () {
        //巡检执行效率饼图
        if (this.data.chartObj.pieChartObj.length) {
            var pieChart = this.data.chartObj.pieChartObj[0];
        } else {
            var pieChart = echarts.init(document.getElementById('pieChart0'), null, {
                "renderer": "svg"
            });
            this.data.chartObj.pieChartObj.push(pieChart);
        }
        var colorlist = [];
        var desclist = [];
        var datalist = [];
        this.data.chartData.rcwo.pie.datalist.slice(0, -1).forEach(function (element) {
            desclist.push(element.description);
            datalist.push({
                value: element.total,
                name: element.description
            });
            colorlist.push(element.color);
        });
        var option = {
            tooltip: {
                formatter: "{b} : {c} ({d}%)"
            },
            legend: {
                y: 'top',
                x: 'left',
                data: desclist
            },
            series: [{
                type: 'pie',
                radius: '55%',
                center: ['50%', '60%'],
                data: datalist
            }],
            color: colorlist
        };
        pieChart.resize();
        pieChart.setOption(option, true);
    };
    $scope.createRcwoBarChart = function () {
        //巡检执行效率柱状图
        if (this.data.chartObj.barChartObj.length) {
            var barChart = this.data.chartObj.barChartObj[0];
        } else {
            var barChart = echarts.init(document.getElementById('barChart0')); //初始化echarts实例
            this.data.chartObj.barChartObj.push();
        }
        var desclist = [];
        var datalist = [];
        var colorlist = [];
        this.data.chartData.rcwo.pie.datalist.forEach(function (element) {
            desclist.push({
                value: element.description,
                textStyle: {
                    fontsize: 12
                }
            });
            datalist.push(element.total);
            colorlist.push(element.color);
        });
        var option = {
            title: {
                text: '',
                subtext: ''
            },
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                },
                formatter: "{b}: {c}"
            },
            grid: {
                top: 20,
                left: '2%',
                right: '2%',
                bottom: '5%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: desclist,
                axisLabel: {
                    interval: 0
                }
            },
            yAxis: {
                show: true,
                type: 'value'
            },
            series: [{
                name: '单数',
                type: 'bar',
                itemStyle: {
                    normal: {
                        color: function color(params) {
                            return colorlist[params.dataIndex];
                        }
                    }
                },
                label: {
                    show: true,
                    position: 'top',
                    formatter: '{c}',
                    textStyle: {
                        fontsize: 12
                    }
                },
                data: datalist
            }]
        };
        if(this.data.lang == "EN") {
            option.xAxis.axisLabel.rotate = -30;
        }
        barChart.resize();
        barChart.setOption(option, true);
    };
    $scope.createRcwoLineChart = function () {
        //巡检执行效率折线图
        if (this.data.chartObj.lineChartObj.length) {
            var lineChart = this.data.chartObj.lineChartObj;
        } else {
            var lineChart = echarts.init(document.getElementById('lineChart0'), null, {
                "renderer": "svg"
            }); //初始化echarts实例
            this.data.chartObj.lineChartObj.push(lineChart);
        }
        var datelist = [];
        var desclist = [];
        var linelist = [];

        this.data.chartData.rcwo.line.datelist.forEach(function (element) {
            datelist.push({
                value: element,
                textStyle: {
                    fontsize: 12
                }
            });
        });
        this.data.chartData.rcwo.line.linelist.forEach(function (element) {
            desclist.push(element.description);
            linelist.push({
                name: element.description,
                type: 'line',
                color: element.color,
                data: element.total
            });
        });
        var option = {
            title: {
                text: ''
            },
            tooltip: {
                trigger: 'axis'
            },
            legend: {
                data: desclist
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                boundaryGap: false,
                data: datelist,
                "axisTick": { //y轴刻度线
                    "show": false
                },
                "splitLine": { //网格线
                    "show": false
                },
                axisLabel: {
                    interval: 0,
                    rotate: -80
                }
            },
            yAxis: {
                type: 'value',
                "textStyle": {
                    "fontSize": 14
                },
                "axisTick": { //y轴刻度线
                    "show": false
                },
                "splitLine": { //网格线
                    "show": false
                }
            },
            series: linelist
        };
        lineChart.resize();
        lineChart.setOption(option, true);
    };
    $scope.createEventPieChart = function () {
        //事件报告统计饼图
        if (this.data.chartObj.pieChartObj.length) {
            var pieChart = this.data.chartObj.pieChartObj[0];
        } else {
            var pieChart = echarts.init(document.getElementById('pieChart0'), null, {
                "renderer": "svg"
            }); //初始化echarts实例
            this.data.chartObj.pieChartObj.push();
        }
        var colorlist = [];
        var desclist = [];
        var datalist = [];
        this.data.chartData.event.pie.datalist.slice(0, -1).forEach(function (element) {
            desclist.push(element.description);
            datalist.push({
                value: element.total,
                name: element.description
            });
            colorlist.push(element.color);
        });
        var option = {
            title: {
                text: '',
                subtext: '',
                x: 'center'
            },
            tooltip: {
                trigger: 'item',
                formatter: "{b} : {c} ({d}%)"
            },
            legend: {
                orient: 'vertical',
                x: 'left',
                data: desclist
            },
            series: [{
                name: '各状态单数',
                type: 'pie',
                radius: '55%',
                center: ['50%', '60%'],
                data: datalist,
                itemStyle: {
                    color: function color(params) {
                        return colorlist[params.dataIndex];
                    },
                    emphasis: {
                        shadowBlur: 10,
                        shadowOffsetX: 0,
                        shadowColor: 'rgba(0, 0, 0, 0.5)'
                    }
                },
                label: {
                    formatter: function formatter(label) {
                        var ret = ""; //拼接加\n返回的类目项
                        var maxLength = 3; //每项显示文字个数
                        var name = label.name;
                        var valLength = name.length; //X轴类目项的文字个数
                        var rowN = Math.ceil(valLength / maxLength); //类目项需要换行的行数
                        if (rowN > 1) //如果类目项的文字大于3,
                        {
                            for (var i = 0; i < rowN; i++) {
                                var temp = ""; //每次截取的字符串
                                var start = i * maxLength; //开始截取的位置
                                var end = start + maxLength; //结束截取的位置
                                temp = name.substring(start, end) + "\n";
                                ret += temp;
                            }
                            return ret;
                        } else {
                            return name;
                        }
                    }
                }
            }]
        };
        pieChart.resize();
        pieChart.setOption(option, true);
    };
    $scope.createEventBarChart = function () {
        //事件报告统计柱状图
        if (this.data.chartObj.barChartObj.length) {
            var barChart = this.data.chartObj.barChartObj[0];
        } else {
            var barChart = echarts.init(document.getElementById('barChart0')); //初始化echarts实例
            this.data.chartObj.barChartObj.push();
        }
        var desclist = [];
        var datalist = [];
        var colorlist = [];
        this.data.chartData.event.pie.datalist.forEach(function (element) {
            desclist.push({
                value: element.description,
                textStyle: {
                    fontSize: 12
                }
            });
            datalist.push(element.total);
            colorlist.push(element.color);
        });
        var option = {
            title: {
                text: '',
                subtext: ''
            },
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                },
                formatter: "{b}: {c}"
            },
            grid: {
                top: 20,
                left: '2%',
                right: '2%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: desclist,
                axisLabel: {
                    interval: 0
                }
            },
            yAxis: {
                show: true,
                type: 'value'
            },
            series: [{
                name: '单数',
                type: 'bar',
                // barWidth: 14,
                itemStyle: {
                    normal: {
                        color: function color(params) {
                            return colorlist[params.dataIndex];
                        },
                        label: {
                            show: true,
                            position: 'top',
                            formatter: '{c}',
                            textStyle: {
                                fontSize: 12
                            }
                        }
                    }
                },
                data: datalist
            }]
        };
        barChart.resize();
        barChart.setOption(option, true);
    };
    $scope.createEventLineChart = function () {
        //事件报告折线图
        if (this.data.chartObj.lineChartObj.length) {
            var lineChart = this.data.chartObj.lineChartObj;
        } else {
            var lineChart = echarts.init(document.getElementById('lineChart0')); //初始化echarts实例
            this.data.chartObj.lineChartObj.push(lineChart);
        }
        var datelist = [];
        var desclist = [];
        var linelist = [];
        this.data.chartData.event.line.datelist.forEach(function (element) {
            datelist.push({
                value: element,
                textStyle: {
                    fontsize: 12
                }
            });
        });
        this.data.chartData.event.line.linelist.forEach(function (element) {
            desclist.push(element.description);
            linelist.push({
                name: element.description,
                type: 'line',
                color: element.color,
                data: element.total
            });
        });
        var option = {
            title: {
                text: ''
            },
            tooltip: {
                trigger: 'axis'
            },
            legend: {
                data: desclist
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                boundaryGap: false,
                data: datelist,
                "axisTick": { //y轴刻度线
                    "show": false
                },
                "splitLine": { //网格线
                    "show": false
                },
                "axisLabel": {
                    interval: 0,
                    rotate: -80
                }
            },
            yAxis: {
                type: 'value',
                "textStyle": {
                    "fontSize": 14
                },
                "axisTick": { //y轴刻度线
                    "show": false
                },
                "splitLine": { //网格线
                    "show": false
                }
            },
            series: linelist
        };
        lineChart.resize();
        lineChart.setOption(option, true);
    };
    $scope.createAbnormalPieChart = function () {
        //巡查异常项统计饼图
        if (this.data.chartObj.pieChartObj[0]) {
            var pieChart = this.data.chartObj.pieChartObj[0];
        } else {
            var pieChart = echarts.init(document.getElementById('pieChart0'), null, {
                "renderer": "svg"
            });
            this.data.chartObj.pieChartObj.push(pieChart);
        }
        var desclist = [];
        var datalist = [];
        this.data.chartData.abnormal.pie.datalist.forEach(function (element) {
            desclist.push(element.description);
            datalist.push({
                value: element.total,
                name: element.description
            });
        });
        var option;
        option = {
            tooltip: {
                formatter: "{b} : {c} ({d}%)"
            },
            legend: {
                // orient: 'vertical',
                x: 'left',
                data: desclist
            },
            series: [{
                type: 'pie',
                radius: '55%',
                center: ['50%', '60%'],
                data: datalist,
                label: {
                    formatter: function formatter(label) {
                        var ret = ""; //拼接加\n返回的类目项
                        var maxLength = 3; //每项显示文字个数
                        var name = label.name;
                        var valLength = name.length; //X轴类目项的文字个数
                        var rowN = Math.ceil(valLength / maxLength); //类目项需要换行的行数
                        if (rowN > 1) //如果类目项的文字大于3,
                        {
                            for (var i = 0; i < rowN; i++) {
                                var temp = ""; //每次截取的字符串
                                var start = i * maxLength; //开始截取的位置
                                var end = start + maxLength; //结束截取的位置
                                temp = name.substring(start, end) + "\n";
                                ret += temp; //拼接最终的字符串
                            }
                            return ret;
                        } else {
                            return name;
                        }
                    }
                }
            }],
            color: this.data.chartData.abnormal.colorlist
        };
        pieChart.resize();
        pieChart.setOption(option, true);
    };
    $scope.createAbnormalBarChart = function () {
        //巡查异常项统计柱状图
        if (this.data.chartObj.barChartObj.length) {
            var barChart = this.data.chartObj.barChartObj[0];
        } else {
            barChart = echarts.init(document.getElementById('barChart0')); //初始化echarts实例
            this.data.chartObj.barChartObj.push(barChart);
        }
        var desclist = [];
        var datalist = [];
        var colorlist = this.data.chartData.abnormal.colorlist;
        this.data.chartData.abnormal.pie.datalist.forEach(function (element) {
            desclist.push({
                value: element.description,
                textStyle: {
                    fontsize: 12
                }
            });
            datalist.push(element.total);
        });
        var option = {
            title: {
                text: '',
                subtext: ''
            },
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                },
                formatter: "{b}: {c}"
            },
            grid: {
                top: 20,
                left: '2%',
                right: '2%',
                bottom: '5%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: desclist,
                boundaryGap: true,
                axisLabel: {
                    interval: 0,
                    rotate: -80
                }
            },
            yAxis: {
                type: 'value'
            },
            series: [{
                name: '单数',
                type: 'bar',
                itemStyle: {
                    normal: {
                        color: function color(params) {
                            return colorlist[params.dataIndex];
                        }
                    }
                },
                label: {
                    show: true,
                    position: 'top',
                    formatter: '{c}',
                    textStyle: {
                        fontsize: 12
                    }
                },
                data: datalist
            }]
        };
        barChart.resize();
        barChart.setOption(option, true);
    };
    $scope.createAbnormalLineChart = function () {
        //巡查异常项统计折线图
        if (this.data.chartObj.lineChartObj.length) {
            var lineChart = this.data.chartObj.lineChartObj[0];
        } else {
            lineChart = echarts.init(document.getElementById('lineChart0'), null, {
                "renderer": "svg"
            }); //初始化echarts实例
            this.data.chartObj.lineChartObj.push(lineChart);
        }
        var datelist = [];
        var desclist = [];
        var linelist = [];
        var colorlist = this.data.chartData.abnormal.colorlist;
        this.data.chartData.abnormal.line.datelist.forEach(function (element) {
            datelist.push({
                value: element,
                textStyle: {
                    fontsize: 12
                }
            });
        });
        this.data.chartData.abnormal.line.linelist.forEach(function (element, index) {
            desclist.push(element.description);
            linelist.push({
                name: element.description,
                type: 'line',
                color: colorlist[index],
                data: element.total
            });
        });
        option = {
            title: {
                text: ''
            },
            tooltip: {
                trigger: 'axis'
            },
            legend: {
                data: desclist
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                boundaryGap: false,
                data: datelist,
                "axisTick": { //y轴刻度线
                    "show": false
                },
                "splitLine": { //网格线
                    "show": false
                },
                axisLabel: {
                    interval: 0,
                    rotate: -80
                }
            },
            yAxis: {
                type: 'value',
                "textStyle": {
                    "fontSize": 14
                },
                "axisTick": { //y轴刻度线
                    "show": false
                },
                "splitLine": { //网格线
                    "show": false
                }
            },
            series: linelist
        };
        lineChart.resize();
        lineChart.setOption(option, true);
    };
    $scope.createHrBarChart = function () {
        //人员执行效率柱状图
        if (this.data.chartObj.barChartObj.length) {
            var barChart = this.data.chartObj.barChartObj[0];
        } else {
            var barChart = echarts.init(document.getElementById('barChart0')); //初始化echarts实例
            this.data.chartObj.barChartObj.push();
        }
        var hrlist = [];
        var desclist = [];
        var datalist = [];

        this.data.chartData.hr.hrArr.forEach(function (element, index) {
            hrlist.push({
                value: index & 0 ? element : "\n" + element,
                textStyle: {
                    fontsize: 12
                }
            });
        });
        this.data.chartData.hr.datalist.forEach(function (element) {
            desclist.push(element.description);
            datalist.push({
                name: element.description,
                type: 'bar',
                stack: '效率',
                itemStyle: {
                    normal: {
                        color: element.color
                    }
                },
                label: {
                    show: true,
                    position: 'inside',
                    formatter: '{c}',
                    textStyle: {
                        fontSize: 12
                    }
                },
                barMaxWidth: 30,
                data: element.total
            });
        });
        var option = {
            title: {
                text: '',
                subtext: ''
            },
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            legend: {
                data: desclist
            },
            grid: {
                top: '20%',
                left: '2%',
                right: '2%',
                bottom: '5%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: hrlist,
                axisLabel: {
                    interval: 0,
                    rotate: -30,
                    align: "left"
                }
            },
            yAxis: {
                show: true,
                type: 'value'
            },
            series: datalist
        };
        if(this.data.lang == "EN") {
            option.grid.top = "25%"
        } else {
            option.grid.top = "20%"
        }
        barChart.resize();
        barChart.setOption(option, true);
    };
    $scope.createHrPieChart = function (index) {
        //人员执行效率饼图
        if (this.data.chartObj.pieChartObj[index]) {
            var mycharts = this.data.chartObj.pieChartObj[index];
        } else {
            var mycharts = echarts.init(document.getElementById('pieChart' + index), null, {
                "renderer": "svg"
            });
            this.data.chartObj.pieChartObj[index] = mycharts;
        }
        var title = '';
        var desclist = [];
        var datalist = [];
        if (this.data.chartData.hr.datalist[index]) {
            title = this.data.chartData.hr.datalist[index].description;
            for (var i = 0; i < this.data.chartData.hr.hrArr.length; i++) {
                var element = this.data.chartData.hr.hrArr[i];
                desclist.push(element);
                datalist.push({
                    value: this.data.chartData.hr.datalist[index].total[i],
                    name: element
                });
            }
        }
        var option = {
            title: {
                text: title,
                subtext: '',
                x: 'center'
            },
            tooltip: {
                formatter: "{b} : {c} ({d}%)"
            },
            legend: {
                // orient: 'vertical',
                x: 'left',
                top: 20,
                data: desclist
            },
            series: [{
                type: 'pie',
                radius: '55%',
                center: ['50%', '60%'],
                data: datalist,
                label: {
                    formatter: function formatter(label) {
                        var ret = ""; //拼接加\n返回的类目项
                        var maxLength = 3; //每项显示文字个数
                        var name = label.name;
                        var valLength = name.length; //X轴类目项的文字个数
                        var rowN = Math.ceil(valLength / maxLength); //类目项需要换行的行数
                        if (rowN > 1) //如果类目项的文字大于3,
                        {
                            for (var i = 0; i < rowN; i++) {
                                var temp = ""; //每次截取的字符串
                                var start = i * maxLength; //开始截取的位置
                                var end = start + maxLength; //结束截取的位置
                                temp = name.substring(start, end) + "\n";
                                ret += temp;
                            }
                            return ret;
                        } else {
                            return name;
                        }
                    }
                }
            }],
            color: this.data.chartData.hr.colorlist
        };
        mycharts.resize();
        mycharts.setOption(option, true);
    };

    $scope.back = function () {
        statisticApi.goback();
    };
});

function pullToRefresh() {
    var ele = angular.element(document.getElementById("myCtrl"));
    var scope = ele.scope();
    scope.$apply(function () {
        scope.getData();
    });
}